Class: CSVPlusPlus::GoogleOptions
- Inherits:
-
Struct
- Object
- Struct
- CSVPlusPlus::GoogleOptions
- Defined in:
- lib/csv_plus_plus/google_options.rb
Overview
The Google-specific options a user can supply
attr sheet_id [String] The ID of the Google Sheet to write to
Instance Attribute Summary collapse
-
#sheet_id ⇒ Object
Returns the value of attribute sheet_id.
Instance Method Summary collapse
- #to_s ⇒ String
-
#verbose_summary ⇒ String
Format a string with a verbose description of what we’re doing with the options.
Instance Attribute Details
#sheet_id ⇒ Object
Returns the value of attribute sheet_id
7 8 9 |
# File 'lib/csv_plus_plus/google_options.rb', line 7 def sheet_id @sheet_id end |
Instance Method Details
#to_s ⇒ String
21 22 23 |
# File 'lib/csv_plus_plus/google_options.rb', line 21 def to_s "GoogleOptions(sheet_id: #{sheet_id})" end |
#verbose_summary ⇒ String
Format a string with a verbose description of what we’re doing with the options
12 13 14 15 16 17 18 |
# File 'lib/csv_plus_plus/google_options.rb', line 12 def verbose_summary <<~SUMMARY ## Google Sheets Options > Sheet ID | #{sheet_id} SUMMARY end |