Class: CSVPlusPlus::Entities::EntityWithArguments
- Defined in:
- lib/csv_plus_plus/entities/entity.rb
Overview
An entity that can take other entities as arguments. Current use cases for this are function calls and function definitions
Direct Known Subclasses
Instance Attribute Summary collapse
-
#arguments ⇒ Array<Entity>
readonly
The arguments supplied to this entity.
Attributes inherited from Entity
Instance Method Summary collapse
- #==(other) ⇒ boolean
-
#initialize(type, id: nil, arguments: []) ⇒ EntityWithArguments
constructor
A new instance of EntityWithArguments.
Methods inherited from Entity
#method_missing, #respond_to_missing?
Constructor Details
#initialize(type, id: nil, arguments: []) ⇒ EntityWithArguments
Returns a new instance of EntityWithArguments.
65 66 67 68 |
# File 'lib/csv_plus_plus/entities/entity.rb', line 65 def initialize(type, id: nil, arguments: []) super(type, id:) @arguments = arguments end |
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class CSVPlusPlus::Entities::Entity
Instance Attribute Details
#arguments ⇒ Array<Entity>
The arguments supplied to this entity.
59 60 61 |
# File 'lib/csv_plus_plus/entities/entity.rb', line 59 def arguments @arguments end |
Instance Method Details
#==(other) ⇒ boolean
71 72 73 |
# File 'lib/csv_plus_plus/entities/entity.rb', line 71 def ==(other) super && @arguments == other.arguments end |